<?php
/*
 * Plugin Name: Mimoza Yorumlar
 * Description: Web siteniz üzerinden kullanıcı yorumları ve yıldız derecelendirmeleri alıp yayınlamanızı sağlayan ücretsiz bir WordPress eklentisi. Dökümantasyon için: https://mimozabilisim.com/wordpress-yorum-eklentisi/
 * Version: 2.0xx
 * Author: Mimoza Bilişim (Onur Kalafat)
 * License: GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Documentation: https://mimozabilisim.com/wordpress-yorum-eklentisi/
 */

// Ayarlar sayfasını oluşturma fonksiyonu
function mimoza_yorumlar_settings_page() {
    ?>
    <div class="wrap">
        <h2>Mimoza Yorumlar Ayarları</h2>
        <form method="post" action="options.php">
            <?php settings_fields('mimoza_yorumlar_options_group'); ?>
            <?php do_settings_sections('mimoza_yorumlar'); ?>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Ayarlar menüsüne ayar sayfası ekleme
function mimoza_yorumlar_menu() {
    add_options_page('Mimoza Yorumlar Ayarları', 'Mimoza Yorumlar', 'manage_options', 'mimoza_yorumlar', 'mimoza_yorumlar_settings_page');
}

add_action('admin_menu', 'mimoza_yorumlar_menu');

// Ayarları kaydetmek için gerekli alanların kaydı
function mimoza_yorumlar_register_settings() {
    register_setting('mimoza_yorumlar_options_group', 'mimoza_yorumlar_recaptcha_site_key');
    register_setting('mimoza_yorumlar_options_group', 'mimoza_yorumlar_recaptcha_secret_key');
}

add_action('admin_init', 'mimoza_yorumlar_register_settings');

// Yorum ve derecelendirme post tipi oluşturma
function mimoza_register_review_post_type() {
    $args = array(
        'public' => true,
        'label'  => 'Reviews',
        'supports' => array('title', 'editor', 'author', 'thumbnail', 'excerpt', 'comments'),
    );
    register_post_type('reviews', $args);
}

add_action('init', 'mimoza_register_review_post_type');

// Yorumları işleme fonksiyonu
function handle_form_submission() {
    if (isset($_POST['submit_rating']) && check_admin_referer('submit_rating_nonce', '_rating_nonce')) {
        $name = sanitize_text_field($_POST['name']);
        $email = sanitize_email($_POST['email']);
        $comment = sanitize_textarea_field($_POST['comment']);
        $rating = intval($_POST['rating']);

        $post_id = wp_insert_post(array(
            'post_title'   => wp_strip_all_tags($name . "'s Review"),
            'post_content' => $comment,
            'post_status'  => 'pending',
            'post_type'    => 'reviews',
            'post_author'  => 1,
        ));

        if (!is_wp_error($post_id)) {
            add_post_meta($post_id, 'rating', $rating);

            // Yönlendirme ve teşekkür mesajı
            wp_redirect(add_query_arg('submitted', 'true', get_permalink()));
            exit;
        }
    }
}

add_action('init', 'handle_form_submission');

// Yıldız derecelendirme fonksiyonu
function render_stars($rating) {
    $full_star = '<i class="fas fa-star"></i>';
    $half_star = '<i class="fas fa-star-half-alt"></i>';
    $empty_star = '<i class="far fa-star"></i>';
    $output = '';

    for ($i = 0; $i < 5; $i++) {
        if ($rating >= 1) {
            $output .= $full_star;
        } elseif ($rating > 0) {
            $output .= $half_star;
        } else {
            $output .= $empty_star;
        }
        $rating--;
    }

    return $output;
}

// Yorumları ve derecelendirmeleri gösteren fonksiyon
function display_reviews_and_ratings() {
    $args = array(
        'post_type' => 'reviews',
        'posts_per_page' => -1,
        'orderby' => 'date',
        'order' => 'DESC'
    );

    $reviews_query = new WP_Query($args);

    if ($reviews_query->have_posts()) {
        echo '<div class="reviews-container">';

        while ($reviews_query->have_posts()) {
            $reviews_query->the_post();
            $rating = get_post_meta(get_the_ID(), 'rating', true);
            $author = get_the_title();
            $content = get_the_content();
            $review_date = get_the_date('Y-m-d');

            echo '<div class="review-box">';
            echo '<h3>' . $author . '</h3>';
            echo '<div class="rating">Derecelendirme: ' . render_stars($rating) . ' (' . $rating . '/5)</div>';
            echo '<div class="content">' . $content . '</div>';
            echo '</div>';
        }

        echo '</div>';
    } else {
        echo 'Henüz yorum yapılmamış.';
    }

    wp_reset_postdata();
}

// Kısa kod ile yorumları gösterme
function reviews_ratings_shortcode() {
    ob_start();
    display_reviews_and_ratings();
    return ob_get_clean();
}

add_shortcode('show_reviews_ratings', 'reviews_ratings_shortcode');

// Formu gösteren fonksiyon
function show_rating_form1() {
    if (isset($_POST['submit_rating'])) {
        echo '<p>Teşekkürler! Yorumunuz onaylandıktan sonra yayınlanacak.</p>';
    }

    ?>
    <form action="" method="post">
        <?php wp_nonce_field('submit_rating_nonce', '_rating_nonce'); ?>
        <label for="name">Adınız:</label>
        <input type="text" id="name" name="name" required>

        <label for="email">E-posta Adresiniz:</label>
        <input type="email" id="email" name="email" required>

        <label for="comment">Yorumunuz:</label>
        <textarea id="comment" name="comment" required></textarea>

        <label for="rating">Derecelendirme:</label>
        <div class="star-rating">
            <input type="radio" id="rating5" name="rating" value="5" required><label for="rating5">★★★★★</label>
            <input type="radio" id="rating4" name="rating" value="4"><label for="rating4">★★★★</label>
            <input type="radio" id="rating3" name="rating" value="3"><label for="rating3">★★★</label>
            <input type="radio" id="rating2" name="rating" value="2"><label for="rating2">★★</label>
            <input type="radio" id="rating1" name="rating" value="1"><label for="rating1">★</label>
        </div>

        <input type="submit" name="submit_rating" value="Yorumu Gönder">
    </form>
    <?php
}

// Kısa kod ile formu gösterme
function rating_form_shortcode() {
    ob_start();
    show_rating_form1();
    return ob_get_clean();
}

add_shortcode('musteri_yorumu', 'rating_form_shortcode');

// Font Awesome Enqueue
function enqueue_font_awesome() {
    wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css');
}

add_action('wp_enqueue_scripts', 'enqueue_font_awesome');
